<?php

namespace Litecms\Coupon\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Coupon\Interfaces\CouponRepositoryInterface;

class CouponPublicController extends BaseController
{
    // use CouponWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Coupon\Interfaces\CouponRepositoryInterface $coupon
     *
     * @return type
     */
    public function __construct(CouponRepositoryInterface $coupon)
    {
        $this->repository = $coupon;
        parent::__construct();
    }

    /**
     * Show coupon's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $coupons = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$coupon::$coupon.names'))
            ->view('$coupon::public.coupon.index')
            ->data(compact('$coupons'))
            ->output();
    }

    /**
     * Show coupon's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $coupons = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$coupon::$coupon.names'))
            ->view('$coupon::public.coupon.index')
            ->data(compact('$coupons'))
            ->output();
    }

    /**
     * Show coupon.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $coupon = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$coupon->name . trans('$coupon::$coupon.name'))
            ->view('$coupon::public.coupon.show')
            ->data(compact('$coupon'))
            ->output();
    }

}
