<?php

namespace Litecms\Coupon\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Coupon\Models\Coupon;

class CouponPolicy
{

    /**
     * Determine if the given user can view the coupon.
     *
     * @param UserPolicy $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function view(UserPolicy $user, Coupon $coupon)
    {
        if ($user->canDo('coupon.coupon.view') && $user->isAdmin()) {
            return true;
        }

        return $coupon->user_id == user_id() && $coupon->user_type == user_type();
    }

    /**
     * Determine if the given user can create a coupon.
     *
     * @param UserPolicy $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('coupon.coupon.create');
    }

    /**
     * Determine if the given user can update the given coupon.
     *
     * @param UserPolicy $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function update(UserPolicy $user, Coupon $coupon)
    {
        if ($user->canDo('coupon.coupon.edit') && $user->isAdmin()) {
            return true;
        }

        return $coupon->user_id == user_id() && $coupon->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given coupon.
     *
     * @param UserPolicy $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Coupon $coupon)
    {
        return $coupon->user_id == user_id() && $coupon->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given coupon.
     *
     * @param UserPolicy $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Coupon $coupon)
    {
        if ($user->canDo('coupon.coupon.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given coupon.
     *
     * @param UserPolicy $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Coupon $coupon)
    {
        if ($user->canDo('coupon.coupon.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
